==> haskell-barbies-2.1.1.0-103.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-barbies.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 barbies
version:              2.1.1.0
visibility:           public
id:                   barbies-2.1.1.0-6ZbqhnfOt1s6Yv2N4wASJC
key:                  barbies-2.1.1.0-6ZbqhnfOt1s6Yv2N4wASJC
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  639fa5506e5025c30186444900de9012
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Functor.Barbie Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN

import-dirs:          /usr/lib/ghc-9.6.6/site-local/barbies-2.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/barbies-2.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/barbies-2.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.1.1.0-6ZbqhnfOt1s6Yv2N4wASJC
depends:
    base-4.18.2.1 distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-barbies-2.1.1.0-106-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-barbies.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 barbies
version:              2.1.1.0
visibility:           public
id:                   barbies-2.1.1.0-LHY7HFEpFVxGp7zmtdmQIv
key:                  barbies-2.1.1.0-LHY7HFEpFVxGp7zmtdmQIv
license:              BSD-3-Clause
copyright:            2018 Daniel Gorin
maintainer:           jcpetruzza@gmail.com
author:               Daniel Gorin
homepage:             https://github.com/jcpetruzza/barbies#readme
synopsis:             Classes for working with types that can change clothes.
description:
    Types that are parametric on a functor are like Barbies that have an outfit for each role. This package provides the basic abstractions to work with them comfortably.

category:             Data Structures
abi:                  81b5373a4b993583f5f81b311156f872
exposed:              True
exposed-modules:
    Barbies Barbies.Bare Barbies.Bi Barbies.Constraints
    Barbies.Internal Data.Functor.Barbie Data.Functor.Transformer

hidden-modules:
    Barbies.Generics.Applicative Barbies.Generics.Bare
    Barbies.Generics.Constraints Barbies.Generics.Distributive
    Barbies.Generics.Functor Barbies.Generics.Traversable
    Barbies.Internal.ApplicativeB Barbies.Internal.ApplicativeT
    Barbies.Internal.BareB Barbies.Internal.ConstraintsB
    Barbies.Internal.ConstraintsT Barbies.Internal.Containers
    Barbies.Internal.Dicts Barbies.Internal.DistributiveB
    Barbies.Internal.DistributiveT Barbies.Internal.FunctorB
    Barbies.Internal.FunctorT Barbies.Internal.MonadT
    Barbies.Internal.TraversableB Barbies.Internal.TraversableT
    Barbies.Internal.Trivial Barbies.Internal.Wear
    Barbies.Internal.Wrappers Barbies.Internal.Writer
    Data.Generics.GenericN

import-dirs:          /usr/lib/ghc-9.6.6/site-local/barbies-2.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/barbies-2.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/barbies-2.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-barbies
hs-libraries:         HSbarbies-2.1.1.0-LHY7HFEpFVxGp7zmtdmQIv
depends:
    base-4.18.2.1 distributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-barbies/html/barbies.haddock
haddock-html:         /usr/share/doc/haskell-barbies/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
